==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/base/BasFundSource.md <==
PageAll
===
select @pageTag(){
				t.FUND_SOURCE_ID,
		t.FUND_SOURCE_CODE,
		t.FUND_SOURCE,
		t.FUND_SOURCE_PID,
		t.FUND_SOURCE_TYPE,
		t.FUND_PRIORITIES,
		t.UNDER_DEPT,
		t.IS_REPAY,
		t.DISPLAY_NO,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE
	 @}
from BAS_FUND_SOURCE t
where t.is_use = 'Y'
@if(!isEmpty(search)){
and(
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search# 
)@}
@pageIgnoreTag(){
 order by t.FUND_SOURCE_ID desc
@}


select
===
SELECT 	t.FUND_SOURCE_ID id, 
		T.FUND_SOURCE_PID PID, 
     	t.FUND_SOURCE_CODE text 
 FROM 	BAS_FUND_SOURCE T 
 WHERE 	t.IS_USE = 'Y'
 START WITH T.FUND_SOURCE_PID = #pid#
 CONNECT BY PRIOR T.FUND_SOURCE_ID = T.FUND_SOURCE_PID
 
 treeSelect
===
WITH TMP AS (
with recursive cte as (
select T.FUND_SOURCE_ID,t.Fund_Source as text,
t.Fund_Source as path
  from BAS_FUND_SOURCE t
 where t.is_use = 'Y'
 and t.fund_source_pid = 0
 union  all
 select T.FUND_SOURCE_ID,
 concat(cte.text,'>',t.Fund_Source) as text, 
 substr(concat(cte.text,'>',t.Fund_Source),
              2,
              length(concat(cte.text,'>',t.Fund_Source))) path
  from BAS_FUND_SOURCE t,cte
 where t.is_use = 'Y'
 and cte.fund_source_id = t.fund_source_pid
)select * from cte
),tmp2 as
(with recursive cte as (
SELECT 	t.FUND_SOURCE_ID id, 
		T.FUND_SOURCE_PID PID, 
     	t.FUND_SOURCE text ,
     	p.path  value,
     	t.display_no
 FROM 	BAS_FUND_SOURCE T 
  LEFT JOIN TMP p  on  p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
 WHERE 	t.IS_USE = 'Y'
 @if(!isEmpty(pids)){
	and t.fund_source_pid in ( #join(pids)#)
@}
 and T.FUND_SOURCE_PID = #pid#
 union all 
 SELECT 	t.FUND_SOURCE_ID id, 
		T.FUND_SOURCE_PID PID, 
     	t.FUND_SOURCE text ,
     	p.path  value,
     	t.display_no
 FROM 	BAS_FUND_SOURCE T
 inner join cte on cte.id = t.FUND_SOURCE_PID
  LEFT JOIN TMP p  on  p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
 WHERE 	t.IS_USE = 'Y'
)select cte.* from cte order by cte.display_no)select *  from tmp2
 
delBasFundSourceAndChild
===
UPDATE 	BAS_FUND_SOURCE T 
SET		T.IS_USE='N'
WHERE 	T.FUND_SOURCE_ID in ( 
	SELECT 	A.FUND_SOURCE_ID
	FROM 	BAS_FUND_SOURCE A 
	WHERE 	A.IS_USE = 'Y'
	start with A.FUND_SOURCE_ID = #id#
	connect by prior A.FUND_SOURCE_ID = A.FUND_SOURCE_PID )
	
	
treeSelectPart
===
-- tmp获取从根节点往下遍历的所有节点的全路径和ID
with TMP as (
with recursive cte as (
select
		T.FUND_SOURCE_ID,
		t.Fund_Source as text,
	t.Fund_Source path
from
		BAS_FUND_SOURCE t
where
	t.is_use = 'Y'
	and t.fund_source_pid = 0
union all
select
		T.FUND_SOURCE_ID,
		concat(cte.text, '>', t.Fund_Source) as text,
	substr(concat(cte.text, '>', t.Fund_Source), LOCATE('>', concat(cte.text, '>', t.Fund_Source))+ 1, length(concat(cte.text, '>', t.Fund_Source))) path
from
		BAS_FUND_SOURCE t,
	cte
where
	cte.fund_source_id = t.fund_source_pid 
)
select
	e.FUND_SOURCE_ID,
	e.path
from
	cte e
)
,
-- tmp2查询起始数据为符合条件的起始数据，根据这些起始数据往下查的数据集合
tmp2 as(
 with recursive temp as (
select
	t.FUND_SOURCE_ID id,
	T.FUND_SOURCE_PID PID,
	t.FUND_SOURCE text,
	p.path value
from
	BAS_FUND_SOURCE T
left join TMP p on
	p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
where
	instr(concat(',', #pids#, ','), concat(',', t.fund_source_id, ','))>0
union all
select
	t.FUND_SOURCE_ID id,
	T.FUND_SOURCE_PID PID,
	t.FUND_SOURCE text,
	p.path value
from
	BAS_FUND_SOURCE T
inner join temp on
	temp.id = T.FUND_SOURCE_PID
left join TMP p on
	p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
)
select
	*
from
	temp)
	select
		*
from
		tmp2
 
 
 
treeBasFundSourceAllot
===
SELECT 	m.id, 
		m.PID, 
     	m.text||decode(l.allot_code,'','','-'||l.allot_code) text,
     	m.keyid,
     	m.nodetype,
     	decode(m.nodetype,0,(SELECT decode(count(A.org_id),0,0,1)
     	FROM BAS_SOUCE_ALLOT A WHERE A.org_id=#orgId#
     	AND A.fund_Source_Id=m.keyid)) as checked
     	FROM (select 'j' || t.FUND_SOURCE_ID id ,t.FUND_SOURCE text , t.FUND_SOURCE_ID as keyid,
     	'j'||t.FUND_SOURCE_PID  pid,0 as nodetype,t.display_no
     	from BAS_FUND_SOURCE t WHERE t.IS_USE = 'Y') m
     	left join BAS_SOUCE_ALLOT l on l.fund_Source_Id=m.keyid
     	and l.org_id=#orgId#
START WITH m.pid = 'j0'
CONNECT BY PRIOR m.id = m.pid
ORDER BY m.DISPLAY_NO

queryFundSourceYear
===
with a as
 (select trunc(t.pay_month, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.pay_money, 0) AS month_money
    from fm_pay_total t, fm_pay_detail d
   where d.is_use = 'Y'
     and d.pay_total_id = t.pay_total_id
     and t.is_use = 'Y'
     and t.workflow_status = 3
  union all
  select trunc(t.operator_date, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.price_tax_money, 0) AS month_money
    from fm_receive_total t, fm_receive_detail d
   where t.receive_total_id = d.receive_total_id
     and t.is_use = 'Y'
     and d.is_use = 'Y'
     and t.workflow_status in (3,88)),
b as
 (select a.org_id,
         to_char(a.month, 'yyyy-MM') AS month,
         a.fund_source_id,
         sum(nvl(a.month_money, 0)) AS sum_money
    from a
   group by a.org_id, to_char(a.month, 'yyyy-MM'), a.fund_source_id)
select c.* from (select t.fund_source_id AS id,
       t.fund_source_code,
       t.fund_source AS text,
       t.fund_source_pid AS pid,
       (select sum(b.sum_money)
          from bas_fund_source s
          left join b
            on s.fund_source_id = b.fund_source_id
         where b.month >= #startMonth#
           and b.month < #endMonth#
         start with s.fund_source_id = t.fund_source_id
        connect by s.fund_source_pid = prior s.fund_source_id) AS last_money,
       (select sum(b.sum_money)
          from bas_fund_source s
          left join b
            on s.fund_source_id = b.fund_source_id
         where b.month = #endMonth#      
         start with s.fund_source_id = t.fund_source_id
        connect by s.fund_source_pid = prior s.fund_source_id) AS this_money
  from bas_fund_source t
 where t.is_use = 'Y'
  start with t.fund_source_pid = 0
connect by prior t.fund_source_id = t.fund_source_pid
 order by t.display_no) c,bas_souce_allot al
   WHERE al.is_use='Y'
    and al.org_id = #orgId#
  and c.id = al.fund_source_id
  

findOneDataById
===
WITH recursive cte  AS (
	SELECT b.FUND_SOURCE_ID,b.Fund_Source AS text, b.Fund_Source path_Name  FROM BAS_FUND_SOURCE b WHERE b.is_use = 'Y'  AND b.fund_source_pid = 0
	UNION ALL
	SELECT b.FUND_SOURCE_ID, concat(t.text,'>',b.Fund_Source) AS text,substr((concat(t.text,'>',b.Fund_Source)),LOCATE('>',concat(t.text, '>', b.Fund_Source))+1,length(concat(t.text,'>',b.Fund_Source))) path_Name  FROM BAS_FUND_SOURCE b,cte  t WHERE t.fund_source_id = b.fund_source_pid
)select  cte.*   from cte  where cte.fund_source_id = #id#


countFundSourceMonth
===
with a as
 (select trunc(t.pay_month, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.pay_money, 0) AS month_money
    from fm_pay_total t, fm_pay_detail d
   where d.is_use = 'Y'
     and d.pay_total_id = t.pay_total_id
     and t.is_use = 'Y'
     and t.workflow_status = 3
  union all
  select trunc(t.operator_date, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.price_tax_money, 0) AS month_money
    from fm_receive_total t, fm_receive_detail d
   where t.receive_total_id = d.receive_total_id
     and t.is_use = 'Y'
     and d.is_use = 'Y'
     and t.workflow_status in (3, 88)
  union all
  select trunc(c.collect_month, 'month') AS month,
         c.fund_source_id,
         c.APPLY_ORG,
         nvl(c.TOTAL_COL_MONEY, 0) AS month_money
    from GM_RETAIL_COLLECTION c
   where c.is_use = 'Y'
     and c.workflow_status in (3)),
b as
 (select a.org_id,
         to_char(a.month, 'yyyy-MM') AS month,
         a.fund_source_id,
         sum(nvl(a.month_money, 0)) AS sum_money
    from a
   group by a.org_id, to_char(a.month, 'yyyy-MM'), a.fund_source_id),
x as
 (select t.fund_source_id AS id,
         t.fund_source_code,
         (case
           when length(t.fund_source_code) = 6 then
            t.fund_source || '小计'
           else
            '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;'||t.fund_source
         end) text,
         t.fund_source_pid AS pid,
         (select sum(b.sum_money)
            from bas_fund_source s
            left join b
              on s.fund_source_id = b.fund_source_id
           where b.month >= #startMonth#
             and b.month < #endMonth#
           start with s.fund_source_id = t.fund_source_id
          connect by s.fund_source_pid = prior s.fund_source_id) AS last_money,
         (select sum(b.sum_money)
            from bas_fund_source s
            left join b
              on s.fund_source_id = b.fund_source_id
           where b.month = #endMonth#
           start with s.fund_source_id = t.fund_source_id
          connect by s.fund_source_pid = prior s.fund_source_id) AS this_money
    from bas_fund_source t, bas_souce_allot al
   where t.is_use = 'Y'
     and al.is_use = 'Y'
     and al.org_id = #orgId#
     and length(t.fund_source_code) <= 9
     and length(t.fund_source_code) > 3
     and t.fund_source_id = al.fund_source_id
     and t.is_use = 'Y'
     and SUBSTR(t.fund_source_code, 1, 3) in ('CI1', 'CI2')
   order by t.display_no),
y as --查询净额
 (select null id,
         'CI3' || '.' || SUBSTR(c.fund_source_code, 5, 2) fund_source_code,
         replace(replace(c.text, '流入', ''), '流出', '') || '净额' text,
         null pid,
         sum(c.last_money) last_money,
         sum(c.this_money) this_money
    from (select t.fund_source_id AS id,
                 t.fund_source_code,
                 t.fund_source AS text,
                 t.fund_source_pid AS pid,
                 (select sum(case
                               when SUBSTR(s.fund_source_code, 1, 3) = 'CI1' then
                                b.sum_money
                               else
                                -b.sum_money
                             end)
                    from bas_fund_source s
                    left join b
                      on s.fund_source_id = b.fund_source_id
                   where b.month >= #startMonth#
                     and b.month < #endMonth#
                   start with s.fund_source_id = t.fund_source_id
                  connect by s.fund_source_pid = prior s.fund_source_id) AS last_money,
                 (select sum(case
                               when SUBSTR(s.fund_source_code, 1, 3) = 'CI1' then
                                b.sum_money
                               else
                                -b.sum_money
                             end)
                    from bas_fund_source s
                    left join b
                      on s.fund_source_id = b.fund_source_id
                   where b.month = #endMonth#
                   start with s.fund_source_id = t.fund_source_id
                  connect by s.fund_source_pid = prior s.fund_source_id) AS this_money
            from bas_fund_source t, bas_souce_allot al
           where t.is_use = 'Y'
             and al.is_use = 'Y'
             and al.org_id = #orgId#
             and t.fund_source_id = al.fund_source_id
             and length(t.fund_source_code) = 6
             and SUBSTR(t.fund_source_code, 1, 3) in ('CI1', 'CI2')
           order by t.display_no) c
   group by SUBSTR(c.fund_source_code, 5, 2),
            replace(replace(c.text, '流入', ''), '流出', ''))
select  @pageTag(){
        c.text,nvl(c.last_money,0)last_money,nvl(c.this_money,0)this_money,c.fund_source_code,
       nvl(replace(replace(f.fund_source, '流入', ''), '流出', ''),
           replace(c.text, '净额', '')) type_name
@}
  from (select x.*
          from x
        union all
        select y.* from y) c
  left join bas_fund_source f
    on SUBSTR(c.fund_source_code, 1, 6) = f.fund_source_code
   and f.is_use = 'Y'
@pageIgnoreTag(){
 order by SUBSTR(c.fund_source_code, 5, 2) asc,
          SUBSTR(c.fund_source_code, 1, 3) asc,
          SUBSTR(c.fund_source_code, 8, 2) asc
@}

==> fine-web-0.0.2-20220909.090829-172.jar: beetlsql/base/BasFundSource.md <==
PageAll
===
select @pageTag(){
				t.FUND_SOURCE_ID,
		t.FUND_SOURCE_CODE,
		t.FUND_SOURCE,
		t.FUND_SOURCE_PID,
		t.FUND_SOURCE_TYPE,
		t.FUND_PRIORITIES,
		t.UNDER_DEPT,
		t.IS_REPAY,
		t.DISPLAY_NO,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE
	 @}
from BAS_FUND_SOURCE t
where t.is_use = 'Y'
@if(!isEmpty(search)){
and(
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search#  or 
 upper(t.dic_code) like #search# 
)@}
@pageIgnoreTag(){
 order by t.FUND_SOURCE_ID desc
@}


select
===
SELECT 	t.FUND_SOURCE_ID id, 
		T.FUND_SOURCE_PID PID, 
     	t.FUND_SOURCE_CODE text 
 FROM 	BAS_FUND_SOURCE T 
 WHERE 	t.IS_USE = 'Y'
 START WITH T.FUND_SOURCE_PID = #pid#
 CONNECT BY PRIOR T.FUND_SOURCE_ID = T.FUND_SOURCE_PID

treeSelect
===
WITH TMP AS (
            with recursive cte as (
            select 
                    T.FUND_SOURCE_ID,
                    t.Fund_Source as text, 
                    t.Fund_Source as path 
            from 
                    BAS_FUND_SOURCE t 
            where 
                    t.is_use = 'Y' 
                    and t.fund_source_pid = 0
            union  all
            select 
                    T.FUND_SOURCE_ID, 
                    concat(cte.text,'>',t.Fund_Source) as text, 
                    substr(concat(cte.text,'>',t.Fund_Source), LOCATE('>', concat(cte.text, '>', t.Fund_Source))+ 1, length(concat(cte.text,'>',t.Fund_Source))) path
            from 
                    BAS_FUND_SOURCE t,cte
            where 
                    t.is_use = 'Y'
                    and cte.fund_source_id = t.fund_source_pid
            )
            select * from cte
            )
,tmp2 as
            (
            with recursive cte as (
                                    SELECT 	
                                            t.FUND_SOURCE_ID id, 
                                            T.FUND_SOURCE_PID PID, 
                                            t.FUND_SOURCE text ,
                                            p.path  value,
                                            t.display_no
                                    FROM 	
                                            BAS_FUND_SOURCE T 
                                    LEFT JOIN 
                                            TMP p  on  p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
                                    WHERE 	
                                            t.IS_USE = 'Y'
                                    @if(!isEmpty(pids)){
                                            and t.fund_source_id in ( #join(pids)#)
                                    @}else if(!isEmpty(pid)){
                                            and T.FUND_SOURCE_PID = #pid#
                                    @}
                                    @if(!isEmpty(systemType)){
                                            and t.SYSTEM_TYPE = #systemType#
                                    @}
                                    union all 
                                    SELECT 	
                                            t.FUND_SOURCE_ID id, 
                                            T.FUND_SOURCE_PID PID, 
                                            t.FUND_SOURCE text ,
                                            p.path  value,
                                            t.display_no
                                    FROM 	
                                            BAS_FUND_SOURCE T
                                    inner join 
                                            cte on cte.id = t.FUND_SOURCE_PID
                                    LEFT JOIN 
                                            TMP p  on  p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
                                    WHERE 	
                                            t.IS_USE = 'Y'
                                    )
            select cte.* from cte order by cte.display_no)
select *  from tmp2
 
delBasFundSourceAndChild
===
UPDATE 	BAS_FUND_SOURCE T 
SET		T.IS_USE='N'
WHERE 	T.FUND_SOURCE_ID in ( 
	SELECT 	A.FUND_SOURCE_ID
	FROM 	BAS_FUND_SOURCE A 
	WHERE 	A.IS_USE = 'Y'
	start with A.FUND_SOURCE_ID = #id#
	connect by prior A.FUND_SOURCE_ID = A.FUND_SOURCE_PID )
	
	
treeSelectPart
===
-- tmp获取从根节点往下遍历的所有节点的全路径和ID
with TMP as (
with recursive cte as (
select
		T.FUND_SOURCE_ID,
		t.Fund_Source as text,
	t.Fund_Source path
from
		BAS_FUND_SOURCE t
where
	t.is_use = 'Y'
	and t.fund_source_pid = 0
union all
select
		T.FUND_SOURCE_ID,
		concat(cte.text, '>', t.Fund_Source) as text,
	substr(concat(cte.text, '>', t.Fund_Source), LOCATE('>', concat(cte.text, '>', t.Fund_Source))+ 1, length(concat(cte.text, '>', t.Fund_Source))) path
from
		BAS_FUND_SOURCE t,
	cte
where
	cte.fund_source_id = t.fund_source_pid 
)
select
	e.FUND_SOURCE_ID,
	e.path
from
	cte e
)
,
-- tmp2查询起始数据为符合条件的起始数据，根据这些起始数据往下查的数据集合
tmp2 as(
 with recursive temp as (
select
	t.FUND_SOURCE_ID id,
	T.FUND_SOURCE_PID PID,
	t.FUND_SOURCE text,
	p.path value
from
	BAS_FUND_SOURCE T
left join TMP p on
	p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
where
	instr(concat(',', #pids#, ','), concat(',', t.fund_source_id, ','))>0
union all
select
	t.FUND_SOURCE_ID id,
	T.FUND_SOURCE_PID PID,
	t.FUND_SOURCE text,
	p.path value
from
	BAS_FUND_SOURCE T
inner join temp on
	temp.id = T.FUND_SOURCE_PID
left join TMP p on
	p.FUND_SOURCE_ID = t.FUND_SOURCE_ID
)
select
	*
from
	temp)
	select
		*
from
		tmp2
 
 
 
treeBasFundSourceAllot
===
SELECT 	m.id,  -- 待删除
		m.PID, 
     	m.text||decode(l.allot_code,'','','-'||l.allot_code) text,
     	m.keyid,
     	m.nodetype,
     	decode(m.nodetype,0,(SELECT decode(count(A.org_id),0,0,1)
     	FROM BAS_SOUCE_ALLOT A WHERE A.org_id=#orgId#
     	AND A.fund_Source_Id=m.keyid)) as checked
     	FROM (select 'j' || t.FUND_SOURCE_ID id ,t.FUND_SOURCE text , t.FUND_SOURCE_ID as keyid,
     	'j'||t.FUND_SOURCE_PID  pid,0 as nodetype,t.display_no
     	from BAS_FUND_SOURCE t WHERE t.IS_USE = 'Y') m
     	left join BAS_SOUCE_ALLOT l on l.fund_Source_Id=m.keyid
     	and l.org_id=#orgId#
START WITH m.pid = 'j0'
CONNECT BY PRIOR m.id = m.pid
ORDER BY m.DISPLAY_NO

queryFundSourceYear 
===
with a as -- 待删除
 (select trunc(t.pay_month, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.pay_money, 0) AS month_money
    from fm_pay_total t, fm_pay_detail d
   where d.is_use = 'Y'
     and d.pay_total_id = t.pay_total_id
     and t.is_use = 'Y'
     and t.workflow_status = 3
  union all
  select trunc(t.operator_date, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.price_tax_money, 0) AS month_money
    from fm_receive_total t, fm_receive_detail d
   where t.receive_total_id = d.receive_total_id
     and t.is_use = 'Y'
     and d.is_use = 'Y'
     and t.workflow_status in (3,88)),
b as
 (select a.org_id,
         to_char(a.month, 'yyyy-MM') AS month,
         a.fund_source_id,
         sum(nvl(a.month_money, 0)) AS sum_money
    from a
   group by a.org_id, to_char(a.month, 'yyyy-MM'), a.fund_source_id)
select c.* from (select t.fund_source_id AS id,
       t.fund_source_code,
       t.fund_source AS text,
       t.fund_source_pid AS pid,
       (select sum(b.sum_money)
          from bas_fund_source s
          left join b
            on s.fund_source_id = b.fund_source_id
         where b.month >= #startMonth#
           and b.month < #endMonth#
         start with s.fund_source_id = t.fund_source_id
        connect by s.fund_source_pid = prior s.fund_source_id) AS last_money,
       (select sum(b.sum_money)
          from bas_fund_source s
          left join b
            on s.fund_source_id = b.fund_source_id
         where b.month = #endMonth#      
         start with s.fund_source_id = t.fund_source_id
        connect by s.fund_source_pid = prior s.fund_source_id) AS this_money
  from bas_fund_source t
 where t.is_use = 'Y'
  start with t.fund_source_pid = 0
connect by prior t.fund_source_id = t.fund_source_pid
 order by t.display_no) c,bas_souce_allot al
   WHERE al.is_use='Y'
    and al.org_id = #orgId#
  and c.id = al.fund_source_id
  

findOneDataById
===
WITH recursive cte  AS (
	SELECT b.FUND_SOURCE_ID,b.Fund_Source AS text, b.Fund_Source path_Name  FROM BAS_FUND_SOURCE b WHERE b.is_use = 'Y'  AND b.fund_source_pid = 0
	UNION ALL
	SELECT b.FUND_SOURCE_ID, concat(t.text,'>',b.Fund_Source) AS text,substr((concat(t.text,'>',b.Fund_Source)),LOCATE('>',concat(t.text, '>', b.Fund_Source))+1,length(concat(t.text,'>',b.Fund_Source))) path_Name  FROM BAS_FUND_SOURCE b,cte  t WHERE t.fund_source_id = b.fund_source_pid
)select  cte.*   from cte  where cte.fund_source_id = #id#


countFundSourceMonth
=== 
with a as --待删除
 (select trunc(t.pay_month, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.pay_money, 0) AS month_money
    from fm_pay_total t, fm_pay_detail d
   where d.is_use = 'Y'
     and d.pay_total_id = t.pay_total_id
     and t.is_use = 'Y'
     and t.workflow_status = 3
  union all
  select trunc(t.operator_date, 'month') AS month,
         d.fund_source_id,
         t.org_id,
         nvl(d.price_tax_money, 0) AS month_money
    from fm_receive_total t, fm_receive_detail d
   where t.receive_total_id = d.receive_total_id
     and t.is_use = 'Y'
     and d.is_use = 'Y'
     and t.workflow_status in (3, 88)
  union all
  select trunc(c.collect_month, 'month') AS month,
         c.fund_source_id,
         c.APPLY_ORG,
         nvl(c.TOTAL_COL_MONEY, 0) AS month_money
    from GM_RETAIL_COLLECTION c
   where c.is_use = 'Y'
     and c.workflow_status in (3)),
b as
 (select a.org_id,
         to_char(a.month, 'yyyy-MM') AS month,
         a.fund_source_id,
         sum(nvl(a.month_money, 0)) AS sum_money
    from a
   group by a.org_id, to_char(a.month, 'yyyy-MM'), a.fund_source_id),
x as
 (select t.fund_source_id AS id,
         t.fund_source_code,
         (case
           when length(t.fund_source_code) = 6 then
            t.fund_source || '小计'
           else
            '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;'||t.fund_source
         end) text,
         t.fund_source_pid AS pid,
         (select sum(b.sum_money)
            from bas_fund_source s
            left join b
              on s.fund_source_id = b.fund_source_id
           where b.month >= #startMonth#
             and b.month < #endMonth#
           start with s.fund_source_id = t.fund_source_id
          connect by s.fund_source_pid = prior s.fund_source_id) AS last_money,
         (select sum(b.sum_money)
            from bas_fund_source s
            left join b
              on s.fund_source_id = b.fund_source_id
           where b.month = #endMonth#
           start with s.fund_source_id = t.fund_source_id
          connect by s.fund_source_pid = prior s.fund_source_id) AS this_money
    from bas_fund_source t, bas_souce_allot al
   where t.is_use = 'Y'
     and al.is_use = 'Y'
     and al.org_id = #orgId#
     and length(t.fund_source_code) <= 9
     and length(t.fund_source_code) > 3
     and t.fund_source_id = al.fund_source_id
     and t.is_use = 'Y'
     and SUBSTR(t.fund_source_code, 1, 3) in ('CI1', 'CI2')
   order by t.display_no),
y as --查询净额
 (select null id,
         'CI3' || '.' || SUBSTR(c.fund_source_code, 5, 2) fund_source_code,
         replace(replace(c.text, '流入', ''), '流出', '') || '净额' text,
         null pid,
         sum(c.last_money) last_money,
         sum(c.this_money) this_money
    from (select t.fund_source_id AS id,
                 t.fund_source_code,
                 t.fund_source AS text,
                 t.fund_source_pid AS pid,
                 (select sum(case
                               when SUBSTR(s.fund_source_code, 1, 3) = 'CI1' then
                                b.sum_money
                               else
                                -b.sum_money
                             end)
                    from bas_fund_source s
                    left join b
                      on s.fund_source_id = b.fund_source_id
                   where b.month >= #startMonth#
                     and b.month < #endMonth#
                   start with s.fund_source_id = t.fund_source_id
                  connect by s.fund_source_pid = prior s.fund_source_id) AS last_money,
                 (select sum(case
                               when SUBSTR(s.fund_source_code, 1, 3) = 'CI1' then
                                b.sum_money
                               else
                                -b.sum_money
                             end)
                    from bas_fund_source s
                    left join b
                      on s.fund_source_id = b.fund_source_id
                   where b.month = #endMonth#
                   start with s.fund_source_id = t.fund_source_id
                  connect by s.fund_source_pid = prior s.fund_source_id) AS this_money
            from bas_fund_source t, bas_souce_allot al
           where t.is_use = 'Y'
             and al.is_use = 'Y'
             and al.org_id = #orgId#
             and t.fund_source_id = al.fund_source_id
             and length(t.fund_source_code) = 6
             and SUBSTR(t.fund_source_code, 1, 3) in ('CI1', 'CI2')
           order by t.display_no) c
   group by SUBSTR(c.fund_source_code, 5, 2),
            replace(replace(c.text, '流入', ''), '流出', ''))
select  @pageTag(){
        c.text,nvl(c.last_money,0)last_money,nvl(c.this_money,0)this_money,c.fund_source_code,
       nvl(replace(replace(f.fund_source, '流入', ''), '流出', ''),
           replace(c.text, '净额', '')) type_name
@}
  from (select x.*
          from x
        union all
        select y.* from y) c
  left join bas_fund_source f
    on SUBSTR(c.fund_source_code, 1, 6) = f.fund_source_code
   and f.is_use = 'Y'
@pageIgnoreTag(){
 order by SUBSTR(c.fund_source_code, 5, 2) asc,
          SUBSTR(c.fund_source_code, 1, 3) asc,
          SUBSTR(c.fund_source_code, 8, 2) asc
@}
